@@ -73,7 +73,7 @@ class CommunityCirclePermissions(CirclePermissions):
         if obj is None:
             from djangoldp_community.models import Community
             resolved = resolve(request.path_info)
-            if hasattr(resolved.kwargs, 'slug'):
+            if 'slug' in resolved.kwargs and (resolved.url_name == "community-communitycircle-list" or resolved.url_name == "community-detail"):
                 community = Community.objects.get(slug=resolved.kwargs['slug'])
                 if is_authenticated_user(request.user) and community.members.filter(user=request.user).exists():
                     perms = perms.union({'add'})
@@ -92,7 +92,7 @@ class CommunityProjectPermissions(ProjectPermissions):
         if obj is None:
             from djangoldp_community.models import Community
             resolved = resolve(request.path_info)
-            if hasattr(resolved.kwargs, 'slug'):
+            if 'slug' in resolved.kwargs and (resolved.url_name == "community-communityproject-list" or resolved.url_name == "community-detail"):
                 community = Community.objects.get(slug=resolved.kwargs['slug'])
                 if is_authenticated_user(request.user) and community.members.filter(user=request.user).exists():
                     perms = perms.union({'add'})
@@ -113,7 +113,7 @@ class CommunityJobPermissions(LDPPermissions):
         if obj is None:
             from djangoldp_community.models import Community
             resolved = resolve(request.path_info)
-            if hasattr(resolved.kwargs, 'slug'):
+            if 'slug' in resolved.kwargs and (resolved.url_name == "community-communityjoboffer-list" or resolved.url_name == "community-detail"):
                 community = Community.objects.get(slug=resolved.kwargs['slug'])
                 if is_authenticated_user(request.user) and community.members.filter(user=request.user).exists():
                     perms = perms.union({'add'})
@@ -130,7 +130,7 @@ class CommunityMembersPermissions(CommunityPermissions):
         if obj is None:
             from djangoldp_community.models import Community
             resolved = resolve(request.path_info)
-            if 'slug' in resolved.kwargs:
+            if 'slug' in resolved.kwargs and (resolved.url_name == "community-communitymember-list" or resolved.url_name == "community-detail"):
                 community = Community.objects.get(slug=resolved.kwargs['slug'])
                 if is_authenticated_user(request.user) and community.members.filter(user=request.user).exists():
                     if community.members.get(user=request.user).is_admin:
@@ -149,7 +149,8 @@ class CommunityProfilePermissions(CommunityPermissions):
         if obj is None:
             from djangoldp_community.models import Community
             resolved = resolve(request.path_info)
-            if hasattr(resolved.kwargs, 'slug'):
+            if 'slug' in resolved.kwargs and (resolved.url_name == "community-communityprofile-list" or\
+                resolved.url_name == "community-communityprofile-detail" or resolved.url_name == "community-detail"):
                 community = Community.objects.get(slug=resolved.kwargs['slug'])
                 if is_authenticated_user(request.user) and community.members.filter(user=request.user).exists():
                     if community.members.get(user=request.user).is_admin:
